!-------------------------------------------------------------------------------

!                      Code_Saturne version 3.0.0
!                      --------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2013 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

!===============================================================================
! Purpose:
! -------

!> \file cs_user_modules.f90
!>
!> \brief User-defined module: it allows to create any user array.
!>
!> This file is compiled before all other user Fortran files.
!> To ensure this, it must not be renamed.
!>
!> The user may define an arbitrary number of modules here, even though
!> only one is defined in the example.
!
!-------------------------------------------------------------------------------

module user_module

  ! Example: allocatable user arrays

  double precision,save::sumavdt
  integer, save :: nymax
  integer, ALLOCATABLE,save,DIMENSION(:)   :: corrs,invarc
  double precision, ALLOCATABLE,save,DIMENSION(:) ::ydat
contains

  !=============================================================================

  ! Allocate arrays

  subroutine init_user_module(ncel,ncelet)

    ! Arguments

    integer, intent(in) :: ncel,ncelet

    ! Local variables

    integer :: err = 0

    if (err .eq. 0 .and. .not.allocated(corrs)) then
       allocate(corrs(ncel), stat=err)
    endif
    if (err .eq. 0 .and. .not.allocated(invarc)) then
       allocate(invarc(nymax), stat=err)
    endif

    if (err .eq. 0 .and. .not.allocated(ydat)) then
       allocate(ydat(nymax), stat=err)
    endif

    if (err /= 0) then
      write (*, *) "Error allocating array."
      call csexit(err)
    endif

    return

  end subroutine init_user_module

  !=============================================================================

  ! Free related arrays

  subroutine finalize_user_module

    if (allocated(corrs)) then
       deallocate(corrs)
    endif
    if (allocated(invarc)) then
       deallocate(invarc)
    endif

    if (allocated(ydat)) then
       deallocate(ydat)
    endif
    
  end subroutine finalize_user_module

  !=============================================================================

end module user_module
